#! /usr/bin/python
#-------------------------------------------------------------------------------
#
# Copyright 2014-2020 Cumulus Networks, inc  all rights reserved
#
#-------------------------------------------------------------------------------
#
class datasync(object):
    """
    This class serves as the base class for other CLAGD classes which 
    synchornize data between two CLAGD peers. It is expected that the functions
    defined in this base class will be overridden by the classes which use
    the class as the base. All functions can be called on different threads,
    but are not re-entrant. So care must be taken to protect access to data
    which is not local to the function.
    """

    def __init__(self):
        """
        Constructor: 
        """
        pass

    def __del__(self):
        """
        Destructor:
        """
        pass

    def SignalThreads(self):
        """
        Signal any threads which were started to stop (but don't wait for them)
        """
        pass

    def JoinThreads(self):
        """
        Wait for any threads to stop
        """
        pass

    def GetObjectSize(self):
        """
        Get the size of interesting objects
        """
        pass

    def __str__(self):
        """
        Return local information in human-readable form
        """
        pass

    def EncodedPeerStr(self):
        """
        Return peer information in human-readable form
        """
        pass

    def CollectLocalInfo(self, nlm):
        """
        This function is called on a periodic interval to gather up any 
        information on the local switch which needs to be collected prior to
        sending that information to the peer switch.
        """
        pass

    def EncodeXmlInfo(self, parent):
        """
        Encodes the local information as XML.

        parent - An xml.etree.ElementTree.Element instance which is the parent
            element under which all of the information should be encoded.
        """
        pass

    def DecodeXmlInfo(self, root):
        """
        Decodes XML-encoded information sent from the peer.

        root - The root element of the XML tree
        """
        pass

    def DualIfChange(self, dualIf, enable):
        """
        Called when an interface becomes or is no longer dual connected
        """
        pass

    def MatchIdIfChange(self, dualIf, enable):
        """
        Called when an interface gets or loses a matching clag-id on the peer
        """
        pass

    def ClearPeerInfo(self):
        """
        Removes information which has been obtained from the peer.
        """
        pass

    def ClearLocalInfo():
        """
        Removes information which has been obtained locally.
        """
        pass
